pluralize

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 4, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Overview

Package pluralize pluralizes and singularizes English words.

It is a faithful port of the npm package "pluralize". It handles irregular words (person/people, mouse/mice, ...), uncountable words (fish, sheep, ...) and the usual regular rules (-s, -es, -ies, -ves, ...) while preserving the case of the input where natural.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IsPlural

func IsPlural(word string) bool

IsPlural reports whether the given word is already in plural form.

func IsSingular

func IsSingular(word string) bool

IsSingular reports whether the given word is already in singular form.

func Plural

func Plural(word string) string

Plural returns the plural form of the given word.

func Singular

func Singular(word string) string

Singular returns the singular form of the given word.

Types

This section is empty.

Jump to