package
Version:
v0.2.0
Opens a new window with list of versions in this module.
Published: Jul 5, 2026
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package ipblocklist provides middleware that rejects requests whose client
IP matches a configured blocklist of addresses or CIDR ranges.
New returns middleware that responds with 403 when the request's client IP
matches one of the configured blocklist entries, and otherwise calls next.
type Options struct {
Block []string
}
Options configures the IP blocklist middleware.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.