package
Version:
v0.1.0
Opens a new window with list of versions in this module.
Published: Jul 4, 2026
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package requireauth provides middleware that rejects requests unless an
authenticated user has been placed on the request by earlier middleware.
New returns middleware that responds with 401 unless the configured request
value has been set (for example by an authentication middleware).
type Options struct {
Key string
}
Options configures the require-auth middleware.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.