Documentation
¶
Overview ¶
Package parseurl parses the URL of an incoming HTTP request into its components.
It is a port of the npm package "parseurl". The reference implementation memoizes the parsed URL on the request object; this port simply parses the request's RequestURI (falling back to the request's URL field) on each call.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func OriginalURL ¶
OriginalURL parses the request's original URL. Like Parse, it uses req.RequestURI as the source of the original, unmodified request target.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.