Documentation
¶
Overview ¶
Package pluralize pluralizes and singularizes English words.
It is a faithful port of the npm package "pluralize". It handles irregular words (person/people, mouse/mice, ...), uncountable words (fish, sheep, ...) and the usual regular rules (-s, -es, -ies, -ves, ...) while preserving the case of the input where natural.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IsSingular ¶
IsSingular reports whether the given word is already in singular form.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.